<?php

namespace Drupal\Tests\sku_prefix_promotion_condition\Unit;

use Drupal\commerce_order\Entity\OrderItemInterface;
use Drupal\commerce_product\Entity\ProductVariationInterface;
use Drupal\sku_prefix_promotion_condition\Plugin\Commerce\Condition\SkuPrefix;
use Drupal\Tests\UnitTestCase;

/**
 * Class SkuPrefixUnitTest.
 *
 * @group sku_prefix_promotion_condition
 */
class SkuPrefixUnitTest extends UnitTestCase {

  /**
   * Test different scenarios.
   *
   * @dataProvider provideConfigAndSku
   */
  public function testEvaluateSingle($config, $sku, $expected_result) {
    $prefix_condition = new SkuPrefix([
      'sku_prefix' => $config,
    ], 'bohus', [
      'entity_type' => 'commerce_order_item',
    ]);
    $variation = $this->createMock(ProductVariationInterface::class);
    $variation->method('getSku')
      ->willReturn($sku);
    $order_item = $this->createMock(OrderItemInterface::class);
    $order_item->method('getEntityTypeId')
      ->willReturn('commerce_order_item');
    $order_item->method('getPurchasedEntity')
      ->willReturn($variation);
    $variation->method('getEntityTypeId')
      ->willReturn('commerce_product_variation');
    $this->assertEquals($expected_result, $prefix_condition->evaluate($order_item));
  }

  /**
   * A dataprovider.
   */
  public function provideConfigAndSku() {
    return [
      [
        12,
        1234,
        TRUE,
      ],
      [
        12,
        3456,
        FALSE,
      ],
      [
        '12',
        '1234',
        TRUE,
      ],
      [
        12,
        '1234',
        TRUE,
      ],
      [
        '666,123,999',
        999111,
        TRUE,
      ],
      [
        '666,123,999',
        1999111,
        FALSE,
      ],
    ];
  }

}
